from __future__ import annotations

from typing_extensions import List

from abqpy.decorators import abaqus_class_doc, abaqus_method_doc

from .FluidInflator import FluidInflator
from .Interaction import Interaction


@abaqus_class_doc
class FluidInflatorActivation(Interaction):
    """The FluidInflatorActivation object is used to define the activation of fluid inflators to model the deployment of
    an airbag.

    The FluidInflatorActivation object is derived from the Interaction object.

    .. note::
        This object can be accessed by::

            import interaction
            mdb.models[name].interactions[name]

        The corresponding analysis keywords are:

        - FLUID INFLATOR ACTIVATION

    .. versionadded:: 2025
        The ``FluidInflatorActivation`` class was added.
    """

    #: A String specifying the repository key.
    name: str

    #: A String specifying the name of the step in which the FluidInflator object is created.
    createStepName: str

    #: A List specifying fluid inflators to be activated.
    inflators: List[FluidInflator]

    #: A String specifying the name of the amplitude curve defining a mapping between the inflation time and the actual
    #: time.
    inflationTimeAmplitude: str

    #: A String specifying the name of the amplitude curve by which to modify the mass flow rate.
    massFlowAmplitude: str

    @abaqus_method_doc
    def __init__(
        self,
        name: str,
        createStepName: str,
        inflators: List[FluidInflator],
        inflationTimeAmplitude: str = "",
        massFlowAmplitude: str = "",
    ):
        """This method creates an FluidExchangeActivation object.

        .. note::
            This function can be accessed by::

                mdb.models[name].FluidExchangeActivation

        Parameters
        ----------
        name
            A String specifying the repository key.
        createStepName
            A String specifying the name of the step in which the FluidInflator object is created.
        inflators
            A list specifying fluid inflators to be activated.
        inflationTimeAmplitude
            A string specifying the name of the amplitude curve defining a mapping between the inflation time
            and the actual time.
        massFlowAmplitude
            A string specifying the name of the amplitude curve by which to modify the mass flow rate.

        Returns
        -------
        FluidInflatorActivation
            A FluidInflatorActivation object.
        """
        super().__init__()

    @abaqus_method_doc
    def setValues(
        self,
        exchanges: List,
        amplitude: str,
        inflators: List[FluidInflator],
        inflationTimeAmplitude: str = "",
        massFlowAmplitude: str = "",
    ):
        """This method modifies the FluidInflatorActivation object.

        Parameters
        ----------

        Parameters
        ----------
        inflators
            A list specifying fluid inflators to be activated.
        inflationTimeAmplitude
            A string specifying the name of the amplitude curve defining a mapping between the inflation time
            and the actual time.
        massFlowAmplitude
            A string specifying the name of the amplitude curve by which to modify the mass flow rate.
        """
        ...



from __future__ import annotations

from typing_extensions import List

from abqpy.decorators import abaqus_class_doc, abaqus_method_doc

from ..UtilityAndView.abaqusConstants import OFF, Boolean
from .FluidExchange import FluidExchange
from .Interaction import Interaction


@abaqus_class_doc
class FluidExchangeActivation(Interaction):
    """The FluidExchnageActivation object is used to define the activation of fluid exchanges within the fluid cavity.

    The FluidExchangeActivation object is derived from the Interaction object.

    .. note::
        This object can be accessed by::

            import interaction
            mdb.models[name].interactions[name]

        The corresponding analysis keywords are:

        - FLUID EXCHANGE ACTIVATION

    .. versionadded:: 2025
        The ``FluidExchangeActivation`` class was added.
    """

    #: A String specifying the repository key.
    name: str

    #: A String specifying the name of the step in which the FluidExchange object is created.
    createStepName: str

    #: A List specifying fluid exchanges to be activated.
    exchanges: List[FluidExchange]

    #: A String specifying the name of the amplitude curve defining a mapping between the inflation time and the actual
    #: time.
    amplitude: str

    #: A Boolean specifying the vent and leakage area obstruction by contacted surfaces.
    isBlockage: Boolean

    #: A Boolean specifying if the flow of fluid is only from the first fluid cavity to the second fluid cavity defined
    #: in the FluidExchange object.
    isOnlyOutflow: Boolean

    #: A Float specifying the ratio of the actual surface area over the initial surface area at which you want the fluid
    #: to leak.
    deltaLeakageArea: float

    @abaqus_method_doc
    def __init__(
        self,
        name: str,
        createStepName: str,
        exchanges: List[FluidExchange],
        amplitude: str,
        isBlockage: Boolean = OFF,
        isOnlyOutflow: Boolean = OFF,
        deltaLeakageArea: float = 0.0,
    ):
        """This method creates an FluidExchangeActivation object.

        .. note::
            This function can be accessed by::

                mdb.models[name].FluidExchangeActivation

        Parameters
        ----------
        name
            A String specifying the repository key.
        createStepName
            A String specifying the name of the step in which the FluidExchangeActivation object is created.
        exchanges
            A List specifying fluid exchanges to be activated.
        amplitude
            A String specifying the name of the amplitude curve defining a mapping between the inflation time and the actual
            time.
        isBlockage
            A Boolean specifying the vent and leakage area obstruction by contacted surfaces.
        isOnlyOutflow
            A Boolean specifying if the flow of fluid is only from the first fluid cavity to the second fluid cavity defined
            in the FluidExchange object.
        deltaLeakageArea
            A Float specifying the ratio of the actual surface area over the initial surface area at which you want the fluid
            to leak.

        Returns
        -------
        FluidExchangeActivation
            A FluidExchangeActivation object.
        """
        super().__init__()

    @abaqus_method_doc
    def setValues(
        self,
        exchanges: List[FluidExchange],
        amplitude: str,
        isBlockage: Boolean = OFF,
        isOnlyOutflow: Boolean = OFF,
        deltaLeakageArea: float = 0.0,
    ):
        """This method modifies the FluidExchangeActivation object.

        Parameters
        ----------

        Parameters
        ----------
        exchanges
            A List specifying fluid exchanges to be activated.
        amplitude
            A String specifying the name of the amplitude curve defining a mapping between the inflation time and the actual time.
        isBlockage
            A Boolean specifying the vent and leakage area obstruction by contacted surfaces.
        isOnlyOutflow
            A Boolean specifying if the flow of fluid is only from the first fluid cavity to the second fluid cavity defined in the FluidExchange object.
        deltaLeakageArea
            A Float specifying the ratio of the actual surface area over the initial surface area at which you want the fluid to leak.
        """
        ...



from __future__ import annotations

from typing_extensions import Literal

from abqpy.decorators import abaqus_class_doc

from ..UtilityAndView.abaqusConstants import abaqusConstants as C
from .InteractionState import InteractionState


@abaqus_class_doc
class FluidInflatorActivationState(InteractionState):
    """The FluidInflatorActivationState object stores the propagating data for a FluidInflatorActivation object. One
    instance of this object is created internally by the FluidInflatorActivation object for each step. The instance
    is also deleted internally by the FluidInflatorActivation object.

    The FluidInflatorActivationState object has no constructor or methods.

    The FluidInflatorActivationState object is derived from the InteractionState object.

    .. note::
        This object can be accessed by::

            import interaction
            mdb.models[name].steps[name].interactionStates[name]

    .. versionadded:: 2025
        The ``FluidInflatorActivationState`` class was added.
    """

    #: A SymbolicConstant specifying the propagation state of the inflators member. Possible values are UNSET, SET,
    #: UNCHANGED, and FREED.
    inflatorsState: Literal[C.UNSET, C.SET, C.UNCHANGED, C.FREED]

    #: A String specifying the name of the FluidInflator object associated with this interaction.
    inflators: str

    #: A SymbolicConstant specifying the propagation state of the inflationTimeAmplitude member. Possible values are
    #: UNSET, SET, UNCHANGED, and FREED.
    inflationTimeAmplitudeState: Literal[C.UNSET, C.SET, C.UNCHANGED, C.FREED]

    #: A String specifying the name of the Amplitude object associated with this interaction.
    inflationTimeAmplitude: str

    #: A SymbolicConstant specifying the propagation state of the massFlowAmplitude member. Possible values are UNSET,
    #: SET, UNCHANGED, and FREED.
    massFlowAmplitudeState: Literal[C.UNSET, C.SET, C.UNCHANGED, C.FREED]

    #: A SymbolicConstant specifying the propagation state of the InteractionState object. Possible values are:
    #:
    #: - NOT_YET_ACTIVE
    #: - CREATED
    #: - PROPAGATED
    #: - MODIFIED
    #: - DEACTIVATED
    #: - NO_LONGER_ACTIVE
    #: - TYPE_NOT_APPLICABLE
    #: - INSTANCE_NOT_APPLICABLE
    #: - BUILT_INTO_BASE_STATE
    status: Literal[
        C.NOT_YET_ACTIVE,
        C.CREATED,
        C.PROPAGATED,
        C.MODIFIED,
        C.DEACTIVATED,
        C.NO_LONGER_ACTIVE,
        C.TYPE_NOT_APPLICABLE,
        C.INSTANCE_NOT_APPLICABLE,
        C.BUILT_INTO_BASE_STATE,
    ]



from __future__ import annotations

from abqpy.decorators import abaqus_class_doc, abaqus_method_doc

from .InteractionProperty import InteractionProperty


@abaqus_class_doc
class WearSurfacePropertyAssignment(InteractionProperty):
    """The WearSurfacePropertyAssignment object stores the wear surface property assignment definition for domain
    pairs in ContactExp and ContactStd objects. The WearSurfacePropertyAssignment object has no constructor or
    members.

    .. note::
        This object can be accessed by::

            import interaction
            mdb.models[name].interactions[name].wearSurfacePropertyAssignments

    .. versionadded:: 2025
        The ``WearSurfacePropertyAssignment`` class was added.
    """

    @abaqus_method_doc
    def changeValuesInStep(
        self,
        stepName: str,
        index: int,
        value: str,
    ):
        """This method allows modification of contact property assignments to domain pairs already defined in a given
        step.

        Parameters
        ----------
        stepName
            A String specifying the name of the step in which the contact property assignments are to be modified.
        index
            An Int specifying the position of the contact property assignment whose value is to be modified.
        value
            A String specifying the value of the wear surface property to be assigned to the domain pair whose index is referenced.
        """
        super().__init__()



from __future__ import annotations

from typing_extensions import Literal

from abqpy.decorators import abaqus_class_doc

from ..UtilityAndView.abaqusConstants import Boolean
from ..UtilityAndView.abaqusConstants import abaqusConstants as C
from .InteractionState import InteractionState


@abaqus_class_doc
class FluidExchangeActivationState(InteractionState):
    """The FluidExchangeActivationState object stores the propagating data for a FluidExchangeActivation object. One
    instance of this object is created internally by the FluidExchangeActivation object for each step. The instance
    is also deleted internally by the FluidExchangeActivation object.

    The FluidExchangeActivationState object has no constructor or methods.

    The FluidExchangeActivationState object is derived from the InteractionState object.

    .. note::
        This object can be accessed by::

            import interaction
            mdb.models[name].steps[name].interactionStates[name]

    .. versionadded:: 2025
        The ``FluidExchangeActivationState`` class was added.
    """

    #: A SymbolicConstant specifying the propagation state of the exchanges member. Possible values are UNSET, SET, UNCHANGED, and FREED.
    exchangesState: Literal[C.UNSET, C.SET, C.UNCHANGED, C.FREED]

    #: A String specifying the name of the FluidExchange object associated with this interaction.
    exchanges: str

    #: A SymbolicConstant specifying the propagation state of the amplitude member. Possible values are UNSET, SET, UNCHANGED, and FREED.
    amplitudeState: Literal[C.UNSET, C.SET, C.UNCHANGED, C.FREED]

    #: A String specifying the name of the Amplitude object associated with this interaction.
    amplitude: str

    #: A SymbolicConstant specifying the propagation state of the isBlockage member. Possible values are UNSET, SET, UNCHANGED, and FREED.
    isBlockageState: Literal[C.UNSET, C.SET, C.UNCHANGED, C.FREED]

    #: A Boolean specifying whether to consider vent and leakage area obstruction by contacted surfaces.
    isBlockage: Boolean

    #: A SymbolicConstant specifying the propagation state of the isOnlyOutflow member. Possible values are UNSET, SET, UNCHANGED, and FREED.
    isOnlyOutflowState: Literal[C.UNSET, C.SET, C.UNCHANGED, C.FREED]

    #: A Boolean specifying whether the flow of fluid is allowed only from the first fluid cavity to the second fluid cavity defined in the FluidExchange object.
    isOnlyOutflow: Boolean

    #: A SymbolicConstant specifying the propagation state of the deltaLeakageArea member. Possible values are UNSET, SET, UNCHANGED, and FREED.
    deltaLeakageAreaState: Literal[C.UNSET, C.SET, C.UNCHANGED, C.FREED]

    #: A Float specifying the ratio of the actual surface area over the initial surface area at which you want the fluid to leak.
    deltaLeakageArea: float

    #: A SymbolicConstant specifying the propagation state of the InteractionState object. Possible values are:
    #:
    #: - NOT_YET_ACTIVE
    #: - CREATED
    #: - PROPAGATED
    #: - MODIFIED
    #: - DEACTIVATED
    #: - NO_LONGER_ACTIVE
    #: - TYPE_NOT_APPLICABLE
    #: - INSTANCE_NOT_APPLICABLE
    #: - BUILT_INTO_BASE_STATE
    status: Literal[
        C.NOT_YET_ACTIVE,
        C.CREATED,
        C.PROPAGATED,
        C.MODIFIED,
        C.DEACTIVATED,
        C.NO_LONGER_ACTIVE,
        C.TYPE_NOT_APPLICABLE,
        C.INSTANCE_NOT_APPLICABLE,
        C.BUILT_INTO_BASE_STATE,
    ]



from __future__ import annotations

from typing_extensions import Dict, Literal, Tuple

from abqpy.decorators import abaqus_class_doc, abaqus_method_doc

from ..UtilityAndView.abaqusConstants import CENTROID, NORMAL_TANGENTIAL, OFF, Boolean
from ..UtilityAndView.abaqusConstants import abaqusConstants as C


@abaqus_class_doc
class FreeBody:
    """The FreeBody object defines a section across which resultant forces and moments are computed.

    .. note::
        This object can be accessed by::

            import visualization
            session.freeBodies[name]
    """

    @abaqus_method_doc
    def FreeBodyFromEdges(
        self,
        name: str,
        edges: str,
        summationLoc: Literal[C.SPECIFY, C.CENTROID, C.NODAL_AVERAGE] = CENTROID,
        summationPoint: tuple = (),
        componentResolution: Literal[C.NORMAL_TANGENTIAL, C.CSYS] = NORMAL_TANGENTIAL,
        csysName: str = "",
    ):
        """This method creates a FreeBody object and places it in the freeBodies repository.

        .. note::
            This function can be accessed by::

                session.FreeBodyFromEdges

        Parameters
        ----------
        name
            A string name for the free body.
        edges
            A DisplayGroup leaf object that specifies the physical constituents of the free body.
        summationLoc
            A SymbolicConstant specifying the location of the summation point. Possible values are
            CENTROID, NODAL_AVERAGE and SPECIFY. The default value is CENTROID.
        summationPoint
            A tuple of 3 floats specifying the summation point.
        componentResolution
            A SymbolicConstant specifying the component resolution. Possible values are
            NORMAL_TANGENTIAL and CSYS. The default value is NORMAL_TANGENTIAL.
        csysName
            A string specifying the name of the coordinate system.

        Returns
        -------
        FreeBody
            A FreeBody object.
        """
        ...

    @abaqus_method_doc
    def FreeBodyFromFaces(
        self,
        name: str,
        faces: str,
        summationLoc: Literal[C.SPECIFY, C.CENTROID, C.NODAL_AVERAGE] = CENTROID,
        summationPoint: tuple = (),
        componentResolution: Literal[C.NORMAL_TANGENTIAL, C.CSYS] = NORMAL_TANGENTIAL,
        csysName: str = "",
    ):
        """This method creates a FreeBody object and places it in the freeBodies repository.

        .. note::
            This function can be accessed by::

                session.FreeBodyFromEdges

        Parameters
        ----------
        name
            A string name for the free body.
        faces
            A DisplayGroup leaf object that specifies the physical constituents of the free body.
        summationLoc
            A SymbolicConstant specifying the location of the summation point. Possible values are
            CENTROID, NODAL_AVERAGE and SPECIFY. The default value is CENTROID.
        summationPoint
            A tuple of 3 floats specifying the summation point.
        componentResolution
            A SymbolicConstant specifying the component resolution. Possible values are
            NORMAL_TANGENTIAL and CSYS. The default value is NORMAL_TANGENTIAL.
        csysName
            A string specifying the name of the coordinate system.

        Returns
        -------
        FreeBody
            A FreeBody object.
        """
        ...

    @abaqus_method_doc
    def FreeBodyFromNodesElements(
        self,
        name: str,
        elements: str,
        nodes: str,
        summationLoc: Literal[C.SPECIFY, C.CENTROID, C.NODAL_AVERAGE] = CENTROID,
        summationPoint: tuple = (),
        componentResolution: Literal[C.NORMAL_TANGENTIAL, C.CSYS] = NORMAL_TANGENTIAL,
        csysName: str = "",
    ):
        """This method creates a FreeBody object and places it in the freeBodies repository.

        .. note::
            This function can be accessed by::

                session.FreeBodyFromEdges

        Parameters
        ----------
        name
            A string name for the free body.
        elements
            A DisplayGroup leaf object that specifies the physical constituents of the free body.
        nodes
            A DisplayGroup leaf object that specifies the physical constituents of the free body.
        summationLoc
            A SymbolicConstant specifying the location of the summation point. Possible values are
            CENTROID, NODAL_AVERAGE and SPECIFY. The default value is CENTROID.
        summationPoint
            A tuple of 3 floats specifying the summation point.
        componentResolution
            A SymbolicConstant specifying the component resolution. Possible values are
            NORMAL_TANGENTIAL and CSYS. The default value is NORMAL_TANGENTIAL.
        csysName
            A string specifying the name of the coordinate system.

        Returns
        -------
        FreeBody
            A FreeBody object.
        """
        ...

    @abaqus_method_doc
    def getFreeBodyData(
        self,
        step: int = 0,
        frame: int = 0,
        allActiveStepFrame: Boolean = OFF,
    ) -> Tuple[Tuple[Dict, ...], ...]:
        """This method returns the force and moment data of a FreeBody object.

        .. note::
            This function can be accessed by::

                session.freeBodies[name].getFreeBodyData

        .. versionadded:: 2025
            The ``getFreeBodyData`` method was added.

        Parameters
        ----------
        step
            An Int specifying the step from which to obtain values. The default value is the current step.
        frame
            An Int specifying the frame from which to obtain values. The default value is the current frame.
        allActiveStepFrame
            A Boolean specifying whether to obtain the values from the specified step and frame or from all active steps
            and frames.

        Returns
        -------
        tuple of tuple of dict
            A tuple of tuples of dictionaries, for each requested step and frame, containing the force and moment data.
        """
        ...
        return ()



from __future__ import annotations

from abqpy.decorators import abaqus_class_doc, abaqus_method_doc

from .Interaction import Interaction


@abaqus_class_doc
class FluidInflator(Interaction):
    """The FluidInflator object is used to define a fluid inflator to model deployment of an airbag. The
    FluidInflator object is derived from the Interaction object.

    .. note::
        This object can be accessed by::

            import interaction
            mdb.models[name].interactions[name]

        The corresponding analysis keywords are:

        - FLUID INFLATOR

    .. versionadded:: 2019
        The ``FluidInflator`` class was added.
    """

    @abaqus_method_doc
    def __init__(
        self,
        name: str,
        createStepName: str,
        cavity: str,
        interactionProperty: str,
    ):
        """This method creates a FluidInflator object.

        .. note::
            This function can be accessed by::

                mdb.models[name].FluidInflator

        Parameters
        ----------
        name
            A String specifying the repository key.
        createStepName
            A String specifying the name of the step in which the FluidInflator object is created.
        cavity
            A String specifying the first FluidCavity object associated with this interaction.
        interactionProperty
            A String specifying the FluidInflatorProperty object associated with this interaction.

        Returns
        -------
            A FluidInflator object.
        """
        super().__init__()

    @abaqus_method_doc
    def setValues(self):
        """This method modifies the FluidInflator object."""
        ...



from __future__ import annotations

from abqpy.decorators import abaqus_class_doc, abaqus_method_doc

from ..UtilityAndView.abaqusConstants import OFF, Boolean
from .InteractionProperty import InteractionProperty


@abaqus_class_doc
class WearProperty(InteractionProperty):
    """The WearProperty object defines a wear interaction property.

    The WearProperty object is derived from the InteractionProperty object.

    .. note::
        This object can be accessed by::

            import interaction
            mdb.models[name].interactionProperties[name]

        The corresponding analysis keywords are:

        - FLUID INFLATOR ACTIVATION

    .. versionadded:: 2025
        The ``WearProperty`` class was added.
    """

    @abaqus_method_doc
    def __init__(
        self,
        name: str,
        fricCoefDependency: Boolean = OFF,
        unitlessWearCoefDependency: Boolean = OFF,
        referenceStress: float = 0.0,
        surfaceWearDistanceDependency: Boolean = OFF,
        temperatureDependency: Boolean = OFF,
        contactPressureDependency: Boolean = OFF,
        dependencies: int = 0,
    ):
        """This method creates an WearProperty object.

        .. note::
            This function can be accessed by::

                mdb.models[name].WearProperty

        Parameters
        ----------
        name
            A String specifying the interaction property repository key.
        fricCoefDependency
            A Boolean specifying whether the Archard's wear equation depends explicitly on the friction coefficient.
            The default value is OFF.
        unitlessWearCoefDependency
            A Boolean specifying whether the wear coefficient is dimensionless. The default value is OFF.
        referenceStress
            A Float specifying the value of the reference stress. This parameter is required if
            unitlessWearCoefDependency is ON.
        surfaceWearDistanceDependency
            A Boolean specifying whether the wear coefficient is dependent on the wear distance. The default value is
            OFF.
        temperatureDependency
            A Boolean specifying whether the wear coefficient is dependent on the surface temperature. The default
            value is OFF.
        contactPressureDependency
            A Boolean specifying whether the wear coefficient is dependent on the contact pressure. The default value
            is OFF.
        dependencies
            An Int specifying the number of field variable dependencies. The default value is 0.

        Returns
        -------
        WearProperty
            A WearProperty object.
        """
        super().__init__()
